summaryrefslogtreecommitdiff
path: root/libpod/container.go
diff options
context:
space:
mode:
Diffstat (limited to 'libpod/container.go')
-rw-r--r--libpod/container.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/libpod/container.go b/libpod/container.go
index c8a09fe9e..ffc4c6314 100644
--- a/libpod/container.go
+++ b/libpod/container.go
@@ -246,8 +246,8 @@ func (c *Container) teardownStorage() error {
return nil
}
-// Create creates a container in the OCI runtime
-func (c *Container) Create() (err error) {
+// Init creates a container in the OCI runtime
+func (c *Container) Init() (err error) {
c.lock.Lock()
defer c.lock.Unlock()